# -*- coding: utf-8 -*-

from __future__ import unicode_literals  # unicode support for py2

import re

import click


class APIKeyParamType(click.ParamType):
    """
    Custom ParamType for API key input cleaning and validation
    """
    name = 'API Key Param Type'

    def convert(self, value, param, ctx):
        cleaned_value = value.strip()
        is_valid = re.match(r'[0-9-a-f]{36}', cleaned_value)

        if not is_valid:
            self.fail(
                'Your API Key has to be a 36-character hexadecimal string',
                param,
                ctx)

        return cleaned_value



# -*- coding: utf-8 -*-

"""
heroku_env.exceptions
-----------------------
All exceptions used in the heroku.env code base are defined here.
"""


class HerokuEnvException(Exception):
    """
    Base exception. All other exceptions
    inherit from here.
    """
    pass



# -*- coding: utf-8 -*-

"""Main module."""
from __future__ import unicode_literals  # unicode support for py2

import os

import click


def set_config_var(name, value, app_name):
    command = 'heroku config:set "{}={}" --app {}'.format(
        name, value, app_name
    )
    os.system(command)


def upload_env(app_name, env_file, set_alt):
    use_alt = False
    alt_value = ''

    with open(env_file) as e:

        for line in e:
            line = line.strip()

            # check comments
            if line.startswith("#"):
                # enable --set-alt
                if set_alt and "alt_value=" in line:
                    alt_value = line.split("alt_value=", 1)[1]
                    if alt_value:
                        # use this value for the next env var
                        use_alt = True
                else:
                    click.echo("Skipping comment...")
                # any kind of comment warrants a skip
                continue

            # set env vars
            if "=" in line:
                kv_pair = line.split("=", 1)
                if len(kv_pair) > 1:  # has to at least be of form: k=
                    key = kv_pair[0]

                    if use_alt:
                        value = alt_value
                        use_alt = False
                    else:
                        value = kv_pair[1]

                    # an empty value is fine
                    if key:
                        set_config_var(key, value, app_name)
            else:
                click.echo("Skipping line : Not of the form key=value")



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""
import io
import os
import sys

from setuptools import setup, find_packages

# Package meta-data.
VERSION = '0.3.0'
NAME = 'heroku.env'
DESCRIPTION = "CLI tool to load heroku env vars from local .env files"
URL = 'https://github.com/viseshrp/heroku.env'
EMAIL = 'viseshrprasad@gmail.com'
AUTHOR = 'Visesh Prasad'
REQUIRES_PYTHON = ">=2.7"
REQUIREMENTS = ['future>=0.15.2', 'Click>=6.0', ]
SETUP_REQUIREMENTS = ['pytest-runner', ]
TEST_REQUIREMENTS = ['pytest', ]

with io.open('README.rst', 'r', encoding='utf-8') as readme_file:
    README = readme_file.read()

with io.open('HISTORY.rst', 'r', encoding='utf-8') as history_file:
    HISTORY = history_file.read()

if sys.argv[-1] == 'tags':
    os.system("git tag -a {} -m 'version {}'".format(VERSION, VERSION))
    os.system("git push --tags")
    sys.exit()

if sys.argv[-1] == 'readme':
    print(README)
    sys.exit()

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=README + '\n\n' + HISTORY,
    author=AUTHOR,
    author_email=EMAIL,
    url=URL,
    packages=find_packages(include=['heroku_env']),
    include_package_data=True,
    license="MIT license",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    entry_points={
        'console_scripts': [
            'heroku.env=heroku_env.__main__:main',
        ],
    },
    python_requires=REQUIRES_PYTHON,
    install_requires=REQUIREMENTS,
    keywords='heroku.env heroku env herokuenv heroku_env environment variables load',
    setup_requires=SETUP_REQUIREMENTS,
    test_suite='tests',
    tests_require=TEST_REQUIREMENTS,
    zip_safe=False,
)
